@@ -30,6 +30,25 @@ class CalibrationConstantVersionApi(Base):
         api_url = self.__get_api_url()
         return self.api_get(api_url, params={'name': name})
 
+    def get_calibration_constant_versions_by_detector_conditions_api(
+            self,
+            detector_identifier,
+            calibration_id,
+            condition,
+            karabo_da='',
+            event_at=None,
+            snapshot_at=None):
+        api_url = self.__get_api_url('get_by_detector_conditions')
+        params = {'detector_identifier': detector_identifier,
+                  'calibration_id': str(calibration_id),
+                  'karabo_da': karabo_da,
+                  'event_at': event_at,
+                  'snapshot_at': snapshot_at}
+
+        return self.api_get(api_url,
+                            params=params,
+                            data=json.dumps(condition))
+
     #
     # Private Methods
     #
