@@ -11,7 +11,7 @@ from ..common.generators import generate_unique_name
 
 @pytest.mark.usefixtures('client_cls')
 class CalibrationConstantApiTest(ApiBase, unittest.TestCase):
-    db_cal_const_1 = {
+    db_cal_const1 = {
         'calibration_constant': {
             'name': 'CALIBRATION_CONSTANT_TEST-1_DO_NOT_DELETE',
             'calibration_id': -1,
@@ -20,7 +20,7 @@ class CalibrationConstantApiTest(ApiBase, unittest.TestCase):
             'description': 'Created automatically via seed:seed_tests'
         }
     }
-    db_cal_const_2 = {
+    db_cal_const2 = {
         'calibration_constant': {
             'name': 'CALIBRATION_CONSTANT_TEST-2_DO_NOT_DELETE',
             'calibration_id': -1,
@@ -46,8 +46,8 @@ class CalibrationConstantApiTest(ApiBase, unittest.TestCase):
 
         expect = calibration_const['calibration_constant']
 
-        expect_db_all = [self.db_cal_const_1['calibration_constant'],
-                         self.db_cal_const_2['calibration_constant']]
+        expect_db_all = [self.db_cal_const1['calibration_constant'],
+                         self.db_cal_const2['calibration_constant']]
 
         # Create new entry (should succeed)
         create_entry_resp = self.cal_client.create_calibration_constant_api(
@@ -68,12 +68,12 @@ class CalibrationConstantApiTest(ApiBase, unittest.TestCase):
 
             # Get entry by all calibration constants (should succeed)
             condition_ids = [
-                self.db_cal_const_1['calibration_constant']['condition_id'],
-                self.db_cal_const_2['calibration_constant']['condition_id']]
+                self.db_cal_const1['calibration_constant']['condition_id'],
+                self.db_cal_const2['calibration_constant']['condition_id']]
 
             self.__get_all_calibration_constants_by_conditions_api(
-                self.db_cal_const_1['calibration_constant']['calibration_id'],
-                self.db_cal_const_1['calibration_constant']['detector_type_id'],
+                self.db_cal_const1['calibration_constant']['calibration_id'],
+                self.db_cal_const1['calibration_constant']['detector_type_id'],
                 condition_ids,
                 expect_db_all)
 
@@ -211,8 +211,8 @@ class CalibrationConstantApiTest(ApiBase, unittest.TestCase):
         receive = self.load_response_content(resp)
 
         assert [c['name'] for c in receive] == [
-            self.db_cal_const_2['calibration_constant']['name'],
-            self.db_cal_const_1['calibration_constant']['name'],
+            self.db_cal_const2['calibration_constant']['name'],
+            self.db_cal_const1['calibration_constant']['name'],
         ]
 
         assert resp.status_code == HTTPStatus.OK
