@@ -455,9 +455,42 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             (-4, self.expected_db_04['name']),
         ]
 
+    def test_calibration_constant_versions_by_detector_conditions(self):
+        calibration_ids = [-1, -2]
+        detector_identifier = 'TEST_DET_CI-2'
+        condition = {
+            "parameters_conditions_attributes": [{"parameter_id": "-1",
+                                                  "value": "2.5"},
+                                                 {"parameter_id": "-2",
+                                                  "value": "1.5"}]}
+
+        results = CalibrationConstantVersion.get_closest_by_time_by_detector_conditions(  # noqa
+            self.cal_client, detector_identifier,
+            calibration_ids,
+            condition)
+
+        # sort results
+        data_sorted = sorted(results['data'], key=lambda d: -d['id'])
+
+        assert [(d['id'], d['name'], d['physical_detector_unit']['physical_name']) for d in data_sorted] == [  # noqa
+            (-7, 'CALIBRATION_CONSTANT_VERSION_TEST-7_DO_NOT_DELETE',
+             'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'),
+            (-8, 'CALIBRATION_CONSTANT_VERSION_TEST-8_DO_NOT_DELETE',
+             'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE'),
+            (-9, 'CALIBRATION_CONSTANT_VERSION_TEST-9_DO_NOT_DELETE',
+             'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE'),
+            (-10, 'CALIBRATION_CONSTANT_VERSION_TEST-10_DO_NOT_DELETE',
+             'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'),
+            (-11, 'CALIBRATION_CONSTANT_VERSION_TEST-11_DO_NOT_DELETE',
+             'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE'),
+            (-12, 'CALIBRATION_CONSTANT_VERSION_TEST-12_DO_NOT_DELETE',
+             'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE')
+        ]
+
     #
     # fields_validation
     #
+
     def fields_validation(self, receive, expect):
         assert receive['name'] == expect['name']
         assert receive['file_name'] == expect['file_name']
